@@ -22,9 +22,9 @@ use Digest::MD5 ('md5_base64');
 use Carp;
 use Try::Tiny;
 use List::Util qw(any);
-
-
-with 'MooX::Log::Any';
+use Log::Log4perl;
+use Log::Log4perl ':easy';
+use Log::Contextual qw( :log ), -package_logger => Log::Log4perl->get_logger;
 
 BEGIN {
 	if ($ENV{TEST_VERBOSE}) {
@@ -36,6 +36,7 @@ BEGIN {
 											 category => 'RDF.LinkedData' 
 										  } );
 	}
+	use Log::Contextual -logger => Log::Log4perl->get_logger;
 }
 
 
@@ -47,11 +48,11 @@ RDF::LinkedData - A simple Linked Data server implementation
 
 =head1 VERSION
 
-Version 0.69_06
+Version 0.69_07
 
 =cut
 
- our $VERSION = '0.69_06';
+ our $VERSION = '0.69_07';
 
 
 =head1 SYNOPSIS
@@ -123,7 +124,7 @@ sub BUILD {
 	}
 
  	if ($self->has_endpoint_config) {
-		$self->logger->debug('Endpoint config found with parameters: ' . Dumper($self->endpoint_config) );
+		log_debug {'Endpoint config found with parameters: ' . Dumper($self->endpoint_config) };
 
 		unless (can_load( modules => { 'RDF::Endpoint' => 0.03 })) {
 			throw Error -text => "RDF::Endpoint not installed. Please install or remove its configuration.";
@@ -135,11 +136,11 @@ sub BUILD {
 
 		$self->endpoint(RDF::Endpoint->new($self->model, $self->endpoint_config));
  	} else {
-		$self->logger->info('No endpoint config found');
+		log_info {'No endpoint config found'};
 	}
 
  	if ($self->has_void_config) {
-		$self->logger->debug('VoID config found with parameters: ' . Dumper($self->void_config) );
+		log_debug {'VoID config found with parameters: ' . Dumper($self->void_config) };
 
 		unless (can_load( modules => { 'RDF::Generator::Void' => 0.04 })) {
 			throw Error -text => "RDF::Generator::Void not installed. Please install or remove its configuration.";
@@ -152,10 +153,10 @@ sub BUILD {
 														  dataset_uri => $dataset_uri,
 														  namespaces_as_vocabularies => $self->void_config->{namespaces_as_vocabularies}));
 		if ($self->has_fragments) {
-			$self->logger->debug('Triple Pattern Fragments config found with parameters: ' . Dumper($self->fragments_config) );
+			log_debug {'Triple Pattern Fragments config found with parameters: ' . Dumper($self->fragments_config) };
 		}
  	} else {
-		$self->logger->info('No VoID config found');
+		log_info {'No VoID config found'};
 	}
 }
 
@@ -341,7 +342,7 @@ sub response {
 			}
 		}
 
-		$self->logger->debug('Getting fragment with this selector ' . Dumper(\%statement));
+		log_debug {'Getting fragment with this selector ' . Dumper(\%statement) };
 		return _client_error($response, 'Returning the whole database not allowed') unless any { defined } values(%statement);
 		my $output_model = $self->_common_fragments_control;
 
@@ -388,7 +389,7 @@ sub response {
 		  $response->headers->header('ETag' => '"' . $self->last_etag . '"');
 		}
 		my $body = $s->serialize_model_to_string($output_model);
-		$self->logger->trace("Fragment message body is $body");
+		log_trace { "Fragment message body is $body" };
 		$response->headers->content_type($ct);
 		$response->body(encode_utf8($body));
 		return $response;
@@ -402,7 +403,7 @@ sub response {
 	my $type = $self->type;
 	$self->type('');
 	my $node = $self->my_node($uri);
-	$self->logger->info("Try rendering '$type' page for subject node: " . $node->as_string);
+	log_info{"Try rendering '$type' page for subject node: " . $node->as_string};
 	if ($self->count($node) > 0) {
 		if ($type) {
 			my $preds = $self->helper_properties;
@@ -414,15 +415,15 @@ sub response {
 				return $response;
 			}
 
-			$self->logger->debug("Will render '$type' page ");
+			log_debug {"Will render '$type' page " };
 			if ($headers_in->can('header') && $headers_in->header('Accept')) {
-				$self->logger->debug('Found Accept header: ' . $headers_in->header('Accept'));
+				log_debug {'Found Accept header: ' . $headers_in->header('Accept') };
 			} else {
 				$headers_in->header('Accept' => 'application/rdf+xml');
 				if ($headers_in->header('Accept')) {
-					$self->logger->warn('Setting Accept header: ' . $headers_in->header('Accept'));
+					log_warn { 'Setting Accept header: ' . $headers_in->header('Accept') };
 				} else {
-					$self->logger->warn('No content type header can be set');
+					log_warn { 'No content type header can be set' };
 				}
 			}
 			$response->status(200);
@@ -442,7 +443,7 @@ sub response {
 				my $preds = $self->helper_properties;
 				$newurl = $preds->page($node);
 			}
-			$self->logger->debug('Will do a 303 redirect to ' . $newurl);
+			log_debug {'Will do a 303 redirect to ' . $newurl };
 			$response->headers->header('Location' => $newurl);
 			$response->headers->header('Vary' => join(", ", qw(Accept)));
 		}
@@ -508,7 +509,7 @@ sub my_node {
     
 	# not happy with this, but it helps for clients that do content sniffing based on filename
 	$iri =~ s/.(nt|rdf|ttl)$//;
-	$self->logger->info("Subject URI to be used: $iri");
+	log_info { "Subject URI to be used: $iri" };
 	return RDF::Trine::Node::Resource->new( $iri );
 }
 
@@ -579,7 +580,7 @@ sub _content {
 			$iter = $iter->concat($hmmodel->as_stream);
 		}
 		$output{body} = $s->serialize_iterator_to_string ( $iter );
-		$self->logger->trace("Message body is $output{body}");
+		log_trace { "Message body is $output{body}" };
 
 	} else {
 		$self->{_type} = 'page';
@@ -640,7 +641,7 @@ sub _negotiate {
 																					'application/xhtml+xml' => 'xhtml'
 																				  }
 																	);
-		$self->logger->debug("Got $ct content type");
+		log_debug { "Got $ct content type" };
 		1;
 	} or do {
 		my $response = Plack::Response->new;
